@@ -10,7 +10,9 @@ class CreateFileReport(CreateReport):
         super().__init__(*args, **kwargs)
         self.filename = filename or self.filename
         if not self.filename:
-            raise NotConfigured("You must define a template output file.")
+            raise NotConfigured(
+                "You must provide a value for SPIDERMON_REPORT_FILENAME setting."
+            )
 
     @classmethod
     def from_crawler_kwargs(cls, crawler):
