@@ -2,9 +2,8 @@ import logging
 
 import json
 from scrapy.utils.misc import load_object
-import six
-from six.moves.urllib.parse import urlparse
-from six.moves.urllib.request import urlopen
+from urllib.parse import urlparse
+from urllib.request import urlopen
 
 logger = logging.getLogger(__name__)
 
@@ -15,20 +14,16 @@ def get_schema_from(source):
         try:
             return json.loads(schema)
         except Exception as e:
-            logger.exception(
-                str(e) + "\nCould not parse schema from '{}'".format(source)
-            )
+            logger.exception(str(e) + f"\nCould not parse schema from '{source}'")
     elif source.endswith(".json"):
-        with open(source, "r") as f:
+        with open(source) as f:
             try:
                 return json.load(f)
             except Exception as e:
-                logger.exception(
-                    str(e) + "\nCould not parse schema in '{}'".format(source)
-                )
+                logger.exception(str(e) + f"\nCould not parse schema in '{source}'")
     else:
         schema = load_object(source)
-        if isinstance(schema, six.string_types):
+        if isinstance(schema, str):
             return json.loads(schema)
         return schema
 
@@ -46,4 +41,4 @@ def get_contents(url):
         with urlopen(url) as f:
             return f.read().decode("utf-8")
     except Exception as e:
-        logger.exception(str(e) + "\nFailed to get '{}'".format(url))
+        logger.exception(str(e) + f"\nFailed to get '{url}'")
