@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 from spidermon.exceptions import NotConfigured
 
 
@@ -12,18 +11,18 @@ class Context(dict):
     """
 
     def __init__(self, *args, **kwargs):
-        super(Context, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._notconfigured = []
 
     def __getitem__(self, item):
         if item in self._notconfigured:
-            raise NotConfigured("{} not available!".format(item))
-        return super(Context, self).__getitem__(item)
+            raise NotConfigured(f"{item} not available!")
+        return super().__getitem__(item)
 
     def extend_via_attrs(self, obj, attrs):
         """Extend context with names of object attributes and their values"""
         for attr in attrs:
             try:
-                super(Context, self).__setitem__(attr, getattr(obj, attr))
+                super().__setitem__(attr, getattr(obj, attr))
             except NotConfigured:
                 self._notconfigured.append(attr)
