@@ -3,14 +3,12 @@ import json
 from collections import OrderedDict
 import warnings
 
-import six
-
 
 def getdictorlist(crawler, name, default=None):
     value = crawler.settings.get(name, default)
     if value is None:
         return {}
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         try:
             return json.loads(value, object_pairs_hook=OrderedDict)
         except ValueError:
