@@ -12,10 +12,10 @@ def line_title(title, length=DEFAULT_LINE_LENGTH, char=DEFAULT_LINE_CHAR):
     title_length = len(title) + 2
     left_length = (length - title_length) // 2
     right_length = left_length + length - title_length - left_length * 2
-    return "%s %s %s" % (char * left_length, title, char * right_length)
+    return "{} {} {}".format(char * left_length, title, char * right_length)
 
 
-class Message(object):
+class Message:
     def __init__(self, text=None):
         self.msg = text or ""
 
